// *-c++-*-
//===========================================================
//=     University of Illinois at Urbana/Champaign          =
//=     Department of Computer Science                      =
//=     Dr. Dan Roth - Cognitive Computation Group          =
//=                                                         =
//=  Project: Snow                                          =
//=                                                         =
//=   Module: Usage.h                                       =
//=  Version: 2.1                                           =
//=   Author: Andrew Carlson                                =
//=     Date: xx/xx/99                                      = 
//=                                                         =
//= Comments:                                               =
//===========================================================

#ifndef __USAGE_H__
#define __USAGE_H__

char* usage[] = 
{"SNOW\n",
"\n",
"NAME\n",
"      snow - Sparse Network of Winnows learning system\n",
"     \n",
"SYNOPSIS\n",
"      snow -train -I inputfile -F networkfile [ -ABcdePrsTvW ]\n",
"      snow -test -I inputfile -F networkfile [ -bEiloRvw ]\n",
"      snow -evaluate -x example -F networkfile [ -bEloRvw ]\n",
"\n",
"DESCRIPTION\n",
"     snow can be run in the following modes: \n",
"    \n",
"     -train: The system is run in training mode and the input file is considered\n",
"     to be a set of labeled training examples. \n",
"     -test: The system is run in a batch test mode.  The input file consists of\n",
"     examples which are classified by the system.\n",
"     -evaluate: The system classifies a single example given as a parameter to\n",
"     the program.\n",
"    \n",
"     Depending on the mode chosen, some options are required, some are optional,\n",
"     and some are superfluous.\n",
"~",
"OPTIONS\n",
"     \n",
"     Required options for mode -train:\n",
"     \n",
"     -F network_file : Specifies the name of a file in which the resulting\n",
"     network is written to after training.\n",
"     -I input_file : Specifies the name of a file from which the training\n",
"     examples are read from.\n",
"     \n",
"     Architecture definition options for mode -train: \n",
"    \n",
"     If no architecture is given, a default Winnow algorihm will be used. \n",
"\n",
"     -A architecture_file: Specifies the name of a file from which to read the\n",
"     algorithm definition.\n",
"     -B :targets : Adds a Naive Bayes algorithm to the network for the given\n",
"     targets.\n",
"     -P :targets : Adds a Perceptron algorithm with default parameters to the \n",
"     network for the given targets. \n",
"     -P learning_rate,threshold,default_weight:targets : Adds a Perceptron\n",
"     algorithm to the network for the given targets. \n",
"     -W :targets : Adds a Winnow algorithm with default parameters to the \n",
"     network for the given targets. \n",
"~",
"     -W alpha,beta,threshold,default_weight:targets : Adds a Winnow algorithm to\n",
"     the network for the given targets. \n",
"\n",
"     Other Options for mode -train:\n",
"\n",
"     -c <i> : Specifies an interval, as a number of examples presented, at which\n",
"     to output a snapshot of the network.  If not specified, the network is only\n",
"     written out at the end of testing.\n",
"     -d <none | abs:thresh | rel> : Specifies the discarding method, if any \n",
"     (default none).\n",
"     -e <i> : This option sets the eligibility threshold (default 2).\n",
"     -m <+ | -> : This option specifies whether to train with multiple labels.\n",
"     If -m + is specified, targets in an example will not be presented as\n",
"     features for other targets.  Otherwise, targets present in an example will\n",
"     act as features for other targets. \n",
"     -r <i> : This option sets the number of cycles through the training data\n",
"     (default 2).\n",
"     -s <s | f> : Specifies whether to use the sparse or full network option\n",
"     (defaults to sparse).\n",
"     -T testing_file : This option specifies a file which test examples are\n",
"     evaluated after training is finished.  All options which may be used for\n",
"     test mode may be used if the -T option is used. \n",
"     -v <off | min | med | max>: Specifies verbosity level (default min)\n",
"~",
"     Required options for mode -test:\n",
"\n",
"     -F networkfile : Specifies the name of a file from which the network used\n",
"     for testing is read. \n",
"     -I inputfile :  Specifies the name of a file from which the testing\n",
"     examples are read from.\n",
"     \n",
"     Required options for mode -evaluate:\n",
"\n",
"     -F network_file : Specifies the name of a file from which the network used\n",
"     for evaluation is read. \n",
"     -x example : Specifies the example which is to be evaluated.\n",
"     \n",
"     Other options for modes -test and -evaluate:\n",
"     \n",
"     -b bayesSmoothing : Specifies the smoothing parameter to be used in Bayes\n",
"     learners (default 20.0).\n",
"     -E errorfile : Specifies the name of a file in which to write information\n",
"     about mistakes during testing.  \n",
"     -i < + | - > : This option specifies whether incremental learning should\n",
"     be used.  If -i + is specified, test examples will also be presented to\n",
"     the network as training examples, and the resulting network will be \n",
"     written out at the end of testing with .new appended to its filename  \n",
"~",
"     (default -i -). \n",
"     -l < + | - > : This option specifies whether test examples are labeled or\n",
"     not. \n",
"     -o < accuracy | competition | allpredict | allactivations | allboth > :\n",
"     Specifies which output mode to use when reporting test results.\n",
"        accuracy : This mode requires labeled examples.  Output is given as a\n",
"        percentage accuracy for all of the test examples.\n",
"        winners : The mode outputs the targetID with the highest activation\n",
"        for each example.\n",
"        allpredictions : This mode outputs, for each example, a list of all \n",
"        targets and their predictions (0 for false, 1 for true).  The target \n",
"        with the highest activation will be predicted as true, all others false.\n",
"        allactivations : This mode outputs, for each example, a list of all\n",
"        targets and their activations.\n",
"        allboth : This mode outputs, for each example, a list of all targets and\n",
"        both their activations and predictions.\n",
"\n",
"     -R resultsfile : Specifies the name of a file in which to write the results\n",
"     of testing.  If not specified, results are written to the console.\n",
"     -v <off | min | med | max>: Specifies verbosity level (default min)\n",
"     -w smoothing : Specifies a smoothing value for winnow and perceptron\n",
"     learners (default 0.00).\n",
"~ \n",
"EXAMPLES\n",
"\n",
"      snow -train -F myfile.net -I mytrain.feat -W :0,1\n",
"      \n",
"      This invokes snow in training mode with network file \"myfile.net\", trains\n",
"      from examples in file \"mytrain.feat\", and uses a Winnow algorithm with\n",
"      default parameters and targets 0 and 1. \n",
"\n",
"&"};
#endif

